package com.ruoyi.invest.mapper;

import java.util.List;
import com.ruoyi.invest.domain.FutureStocks;
import com.ruoyi.invest.domain.dto.FutureStocksDto;
import com.ruoyi.invest.domain.vo.FutureStocksVo;

/**
 * 期货股票基本信息Mapper接口
 *
 * @author tianyongbao
 * @date 2024-03-19
 */
public interface FutureStocksMapper
{
    /**
     * 查询期货股票基本信息
     *
     * @param id 期货股票基本信息主键
     * @return 期货股票基本信息
     */
    public FutureStocksVo selectFutureStocksById(Long id);

    /**
     * 查询期货股票基本信息列表
     *
     * @param futureStocksDto 期货股票基本信息
     * @return 期货股票基本信息集合
     */
    public List<FutureStocksVo> selectFutureStocksList(FutureStocksDto futureStocksDto);

    /**
     * 新增期货股票基本信息
     *
     * @param futureStocks 期货股票基本信息
     * @return 结果
     */
    public int insertFutureStocks(FutureStocks futureStocks);

    /**
     * 修改期货股票基本信息
     *
     * @param futureStocks 期货股票基本信息
     * @return 结果
     */
    public int updateFutureStocks(FutureStocks futureStocks);

    /**
     * 删除期货股票基本信息
     *
     * @param id 期货股票基本信息主键
     * @return 结果
     */
    public int deleteFutureStocksById(Long id);

    /**
     * 批量删除期货股票基本信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFutureStocksByIds(Long[] ids);

    /**
     * 逻辑删除期货股票基本信息
     *
     * @param id 期货股票基本信息主键
     * @return 结果
     */
    public int removeFutureStocksById(Long id);

    /**
     * 批量逻辑删除期货股票基本信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int removeFutureStocksByIds(Long[] ids);
}
